@@ -74,25 +74,22 @@
 #' 
 
 inspect_apsim <- function(file = "", src.dir = ".", 
-                          node = c("Clock","Weather","Soil","SurfaceOrganicMatter",
-                                        "Crop","Manager","Other"),
-                          soil.child = c("Metadata","Water","OrganicMatter", "Nitrogen",
-                                         "Analysis","InitialWater","Sample",
-                                         "SWIM"),
+                          node = c("Clock", "Weather", "Soil", "SurfaceOrganicMatter", "Crop", "Manager", "Other"),
+                          soil.child = c("Metadata", "Water", "OrganicMatter", "Nitrogen", "Analysis", "InitialWater", "Sample", "SWIM"),
                           parm = NULL,
                           digits = 3,
                           print.path = FALSE){
   
-  file.names <- dir(path = src.dir, pattern=".apsim$",ignore.case=TRUE)
+  file.names <- dir(path = src.dir, pattern=".apsim$", ignore.case=TRUE)
   
-  if(length(file.names)==0){
+  if(length(file.names) == 0){
     stop("There are no .apsim files in the specified directory to inspect.")
   }
   
   node <- match.arg(node)
   soil.child <- match.arg(soil.child)
   
-  if(print.path & missing(parm) & node != "Weather") 
+  if(print.path && missing(parm) && node != "Weather") 
     stop("parm should be specified when print.path is TRUE")
   
   ## This matches the specified file from a list of files
@@ -100,7 +97,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
   file <- match.arg(file, file.names)
   
   ## Read the file
-  apsim_xml <- xml2::read_xml(paste0(src.dir,"/",file))
+  apsim_xml <- xml2::read_xml(paste0(src.dir, "/", file))
   
   ## parm.path.0 is the 'root' path
   parm.path <- NULL
@@ -111,29 +108,29 @@ inspect_apsim <- function(file = "", src.dir = ".",
     parm.path.0 <- ".//clock"
     parms <- c("start_date", "end_date")
     for(i in parms){
-      clock.node <- xml2::xml_find_first(apsim_xml, paste0(parm.path.0,"/",i))
-      cat(i,":",xml2::xml_text(clock.node),"\n")
+      clock.node <- xml2::xml_find_first(apsim_xml, paste0(parm.path.0, "/", i))
+      cat(i, ":", xml2::xml_text(clock.node), "\n")
     }
     if(!missing(parm)){
-      parm.path.1 <- paste0(parm.path.0,"/",parm)
+      parm.path.1 <- paste0(parm.path.0, "/", parm)
     }
   }
   
   if(node == "Weather"){
     parm.path.0 <- ".//metfile/filename"
     weather.filename.node <- xml2::xml_find_first(apsim_xml, parm.path.0)
-    cat("Met file:",(xml2::xml_text(weather.filename.node)),"\n")
+    cat("Met file:", (xml2::xml_text(weather.filename.node)), "\n")
   }
   
   ## Extracting soil Depths
   ## May be I should move this function to 'apsim_internals.R'
   ## t2d is "thickness" to "depth"
   t2d <- function(x){
-    x2 <- c(0,x)/10 ## Divide by 10 to go from mm to cm
+    x2 <- c(0, x)/10 ## Divide by 10 to go from mm to cm
     ans <- character(length(x))
     csx2 <- cumsum(x2)
     for(i in 2:length(x2)){
-        ans[i-1] <- paste0(csx2[i-1],"-",csx2[i]) 
+        ans[i-1] <- paste0(csx2[i-1], "-", csx2[i]) 
     }
     ans
   }
@@ -149,19 +146,19 @@ inspect_apsim <- function(file = "", src.dir = ".",
     number.soil.layers <- length(soil.thickness)
     
     ## Print soil type, latitude and longitude
-    cat("Soil Type: ",xml2::xml_text(xml2::xml_find_first(apsim_xml, ".//Soil/SoilType")),"\n")
-    cat("Latitude: ",xml2::xml_text(xml2::xml_find_first(apsim_xml, ".//Soil/Latitude")),"\n")
-    cat("Longitude: ",xml2::xml_text(xml2::xml_find_first(apsim_xml, ".//Soil/Longitude")),"\n")
+    cat("Soil Type: ", xml2::xml_text(xml2::xml_find_first(apsim_xml, ".//Soil/SoilType")),"\n")
+    cat("Latitude: ", xml2::xml_text(xml2::xml_find_first(apsim_xml, ".//Soil/Latitude")),"\n")
+    cat("Longitude: ", xml2::xml_text(xml2::xml_find_first(apsim_xml, ".//Soil/Longitude")),"\n")
     
     if(soil.child == "Metadata"){
-      metadata.parms <- c("SoilType","LocalName","Site","NearestTown","Region","State",
-                          "Country","ApsoilNumber","Latitude","Longitude","YearOfSampling",
-                          "DataSource","Comments","NaturalVegetation")
+      metadata.parms <- c("SoilType", "LocalName", "Site", "NearestTown", "Region", "State",
+                          "Country", "ApsoilNumber", "Latitude", "Longitude", "YearOfSampling",
+                          "DataSource", "Comments", "NaturalVegetation")
       met.dat <- data.frame(parm = metadata.parms, value = NA)
       j <- 1
       for(i in metadata.parms){
         parm.path.0 <- ".//Soil"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.metadata.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         if(length(soil.metadata.node) > 0){
           met.dat[j,1] <- i
@@ -174,17 +171,19 @@ inspect_apsim <- function(file = "", src.dir = ".",
     
     if(soil.child == "Water"){
       ## Crop specific
-      crop.parms <- c("LL","KL","XF")
+      crop.parms <- c("LL", "KL", "XF")
       
-      val.mat <- matrix(NA, ncol = (length(crop.parms)+1),
+      val.mat <- matrix(NA, 
+                        ncol = (length(crop.parms)+1),
                         nrow = number.soil.layers)
+      
       crop.d <- data.frame(val.mat)
       crop.d[,1] <- soil.depths
-      names(crop.d) <- c("Depth",crop.parms)
+      names(crop.d) <- c("Depth", crop.parms)
       j <- 2
       for(i in crop.parms){
         parm.path.0 <- ".//Soil/Water/SoilCrop"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.water.crop.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         crop.d[,j] <- xml2::xml_double(xml2::xml_children(soil.water.crop.node))
         j <- j + 1
@@ -193,15 +192,19 @@ inspect_apsim <- function(file = "", src.dir = ".",
       if(!missing(parm) && parm %in% crop.parms)
           parm.path.0 <- ".//Soil/Water/SoilCrop"
 
-      soil.parms <- c("Thickness","BD","AirDry","LL15","DUL","SAT","KS")
-      val.mat <- matrix(NA, ncol = length(soil.parms),
+      soil.parms <- c("Thickness", "BD", "AirDry", "LL15", "DUL", "SAT", "KS")
+      
+      val.mat <- matrix(NA, 
+                        ncol = length(soil.parms),
                         nrow = number.soil.layers)
+      
       soil.d <- data.frame(val.mat)
       names(soil.d) <- soil.parms
+      
       j <- 1
       for(i in soil.parms){
         parm.path.0 <- ".//Soil/Water"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.water.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         soil.d[,j] <- xml2::xml_double(xml2::xml_children(soil.water.node))
         j <- j + 1
@@ -222,7 +225,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
       j <- 1
       for(i in soil.water.parms){
         parm.path.0 <- ".//Soil/SoilWater"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.water.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         soil.water.d[j,"value"] <- xml2::xml_text(soil.water.node)
         j <- j + 1
@@ -246,7 +249,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
       
       j <- 1
       for(i in swim.parms1){
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         swim.parm.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         swim.parms1.d[j,"value"] <- xml2::xml_text(swim.parm.node)
         j <- j + 1
@@ -265,7 +268,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
       
       j <- 1
       for(i in swim.parms2){
-        parm.path.1.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1.1 <- paste0(parm.path.0, "/", i)
         swim.parm.node <- xml2::xml_find_first(apsim_xml, parm.path.1.1)
         swim.parms2.d[j,"value"] <- xml2::xml_text(swim.parm.node)
         j <- j + 1
@@ -274,16 +277,16 @@ inspect_apsim <- function(file = "", src.dir = ".",
       
       if(!missing(parm) && parm %in% swim.parms2){
         if(grepl("WaterTableDepth",parm,fixed=TRUE)){
-          parm.path.0 <- paste0(parm.path.0,"/","SwimWaterTable")
+          parm.path.0 <- paste0(parm.path.0, "/", "SwimWaterTable")
         }else{
-          parm.path.0 <- paste0(parm.path.0,"/","SwimSubsurfaceDrain")
+          parm.path.0 <- paste0(parm.path.0, "/", "SwimSubsurfaceDrain")
         }
       }
     }
     
     if(soil.child == "Nitrogen"){
       stop("not implemented yet")
-      nitrogen.parms <- c("fom_type","fract_carb","fract_cell","fract_lign")
+      nitrogen.parms <- c("fom_type", "fract_carb", "fract_cell", "fract_lign")
       
       val.mat <- matrix(NA, ncol = length(nitrogen.parms),
                         nrow = 6, 
@@ -292,7 +295,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
       nitro.d <- data.frame(val.mat)
       k <- 1
       for(i in nitrogen.parms){
-        parm.path <- paste0(".//Soil/SoilNitrogen","/",i)
+        parm.path <- paste0(".//Soil/SoilNitrogen", "/", i)
         soil.nitrogen.node <- xml2::xml_find_first(apsim_xml, parm.path)
         nitro.d[,k] <- xml2::xml_text(xml2::xml_children(soil.nitrogen.node))
         k <- k + 1
@@ -303,23 +306,24 @@ inspect_apsim <- function(file = "", src.dir = ".",
     if(soil.child == "OrganicMatter"){
       ## State what are organic matter possible parameters
       ## Will keep these ones hard coded
-      som.parms1 <- c("RootCN","RootWt","SoilCN","EnrACoeff",
-                      "EnrBCoeff")
+      som.parms1 <- c("RootCN", "RootWt", "SoilCN", "EnrACoeff", "EnrBCoeff")
       
       som.d1 <- data.frame(parm = som.parms1, value = NA)
       
       for(i in som.parms1){
         parm.path.0 <- ".//Soil/SoilOrganicMatter"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.som1.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         som.d1[som.d1$parm == i,2] <- xml2::xml_text(soil.som1.node)
       }
       print(knitr::kable(som.d1, digits = digits))
       
-      som.parms2 <- c("Thickness","OC","FBiom","FInert")
+      som.parms2 <- c("Thickness", "OC", "FBiom", "FInert")
       
-      val.mat <- matrix(NA, ncol = (length(som.parms2)+1),
+      val.mat <- matrix(NA, 
+                        ncol = (length(som.parms2)+1),
                         nrow = number.soil.layers)
+      
       val.mat[,1] <- soil.depths
       som.d2 <- as.data.frame(val.mat)
       names(som.d2) <- c("Depth", som.parms2)
@@ -327,7 +331,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
       j <- 2
       for(i in som.parms2){
         parm.path.0 <- ".//Soil/SoilOrganicMatter"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.som2.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         som.d2[,j] <- xml2::xml_text(xml2::xml_children(soil.som2.node))
         j <- j + 1
@@ -341,10 +345,12 @@ inspect_apsim <- function(file = "", src.dir = ".",
     
     if(soil.child == "Analysis"){
       ## I will keep this one hard coded because it is simple
-      analysis.parms <- c("Thickness","PH","EC")
+      analysis.parms <- c("Thickness", "PH", "EC")
       
-      val.mat <- matrix(NA, ncol = (length(analysis.parms)+1),
+      val.mat <- matrix(NA, 
+                        ncol = (length(analysis.parms)+1),
                         nrow = number.soil.layers)
+      
       analysis.d <- as.data.frame(val.mat)
       analysis.d[,1] <- soil.depths
       names(analysis.d) <- c("Depth", analysis.parms)
@@ -352,7 +358,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
       j <- 2
       for(i in analysis.parms){
         parm.path.0 <- ".//Soil/Analysis"
-        parm.path.1 <- paste0(parm.path.1,"/",i)
+        parm.path.1 <- paste0(parm.path.1, "/", i)
         soil.analysis.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         analysis.d[,j] <- xml2::xml_text(xml2::xml_children(soil.analysis.node))
         j <- j + 1
@@ -365,13 +371,13 @@ inspect_apsim <- function(file = "", src.dir = ".",
     }
     
     if(soil.child == "InitialWater"){
-      initialwater.parms <- c("PercentMethod","FractionFull","DepthWetSoil")
+      initialwater.parms <- c("PercentMethod", "FractionFull", "DepthWetSoil")
       
       initial.water.d <- data.frame(parm = initialwater.parms, value = NA)
       
       for(i in initialwater.parms){
         parm.path.0 <- ".//Soil/InitialWater"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.InitialWater.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         initial.water.d[initial.water.d$parm == i,2] <- xml2::xml_text(soil.InitialWater.node)
       }
@@ -383,10 +389,12 @@ inspect_apsim <- function(file = "", src.dir = ".",
     }
     
     if(soil.child == "Sample"){
-      sample.parms <- c("Thickness","NO3","NH4","SW","OC","EC","CL","ESP","PH")
+      sample.parms <- c("Thickness", "NO3", "NH4", "SW", "OC", "EC", "CL", "ESP", "PH")
       
-      val.mat <- matrix(NA, ncol = (length(sample.parms)+1),
+      val.mat <- matrix(NA, 
+                        ncol = (length(sample.parms)+1),
                         nrow = number.soil.layers)
+      
       sample.d <- data.frame(val.mat)
       sample.d[,1] <- soil.depths
       names(sample.d) <- c("Depth", sample.parms)
@@ -394,7 +402,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
       j <- 2
       for(i in sample.parms){
         parm.path.0 <- ".//Soil/Sample"
-        parm.path.1 <- paste0(parm.path.0,"/",i)
+        parm.path.1 <- paste0(parm.path.0, "/", i)
         soil.sample.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
         sample.d[,j] <- xml2::xml_text(xml2::xml_children(soil.sample.node))
         j <- j + 1
@@ -418,7 +426,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
     pools.d <- data.frame(parm = pools.parms, value = NA)
       
     for(i in pools.parms){
-      parm.path.1 <- paste0(pools.path,"/",i)
+      parm.path.1 <- paste0(pools.path, "/", i)
       soil.pools.node <- xml2::xml_find_first(apsim_xml, parm.path.1)
       pools.d[pools.d$parm == i,2] <- xml2::xml_text(soil.pools.node)
     }
@@ -435,7 +443,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
     cat("Crop Type: ",xml2::xml_text(xml2::xml_find_first(apsim_xml, ".//manager/ui/crop")),"\n")
     ## Make sure sowing rule is present
     xfa.manager <- as.vector(unlist(xml2::xml_attrs(xml2::xml_find_all(apsim_xml, ".//manager"))))
-    cat("Management Scripts:", xfa.manager,"\n", sep = "\n")
+    cat("Management Scripts:", xfa.manager, "\n", sep = "\n")
     
     if(missing(parm)) parm.path.0 <- ".//manager"
     
@@ -451,7 +459,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
         stop(paste(parm1, " not found"))
       if(length(find.parm) > 1) stop("parm selection should be unique")
       
-      cat("Selected manager: ", all.manager.names[[find.parm]],"\n")
+      cat("Selected manager: ", all.manager.names[[find.parm]], "\n")
 
       crop <- xml2::xml_find_all(apsim_xml, paste0(".//manager"))[find.parm]
       crop2 <- xml2::xml_find_first(crop, "ui")
@@ -462,7 +470,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
         parm.path.0 <- ".//manager"
       }
       
-      descr <- sapply(xml2::xml_attrs(xml2::xml_children(crop2)),function(x) x[["description"]])
+      descr <- sapply(xml2::xml_attrs(xml2::xml_children(crop2)), function(x) x[["description"]])
       vals <- xml2::xml_text(xml2::xml_children(crop2))
     
       if(is.na(position)){
@@ -503,7 +511,7 @@ inspect_apsim <- function(file = "", src.dir = ".",
     if(!is.null(parm.path.1)){
       parm.path <- parm.path.1
     }
-    cat("Parm path:", parm.path,"\n")
+    cat("Parm path:", parm.path, "\n")
   }
   invisible(parm.path)
 }
